@@ -9,10 +9,16 @@
 (*                                                                     *)
 (***********************************************************************)
 
-val compute : string -> string -> string
+(*
+"$Id: color.mli,v 1.6 2005/03/08 15:15:03 maranget Exp $" 
+*)
+
+type t = Name of string | Hex of string
+
+val compute : string -> string -> t
 val define : string -> string -> string -> unit
 val define_named : string -> string -> string -> unit
-val retrieve : string -> string
+val retrieve : string -> t
 val remove : string -> unit
 
 type saved
