@@ -9,7 +9,7 @@
 (*                                                                     *)
 (***********************************************************************)
 
-let header = "$Id: htmlCommon.ml,v 1.40 2003/03/07 17:25:33 maranget Exp $" 
+let header = "$Id: htmlCommon.ml,v 1.45 2005/01/18 16:25:12 maranget Exp $" 
 
 (* Output function for a strange html model :
      - Text elements can occur anywhere and are given as in latex
@@ -235,7 +235,7 @@ let pretty_stack s = Stack.pretty
 
 let rec pop_out s = match pop s with
 | Normal (a,b,c) -> a,b,c
-| Freeze f       -> raise PopFreeze
+| Freeze _f      -> raise PopFreeze
 (* begin
   if !verbose > 2 then begin
      prerr_string "unfreeze in pop_out" ;
@@ -651,7 +651,7 @@ let par_val last now n =
     else if
       is_header last || last = PRE || last = BLOCKQUOTE
     then n-1
-    else if last = DIV || last = TABLE then n
+    else if last = TABLE then n
     else n+1 in
   if !verbose > 2 then
     Printf.fprintf stderr
@@ -1217,7 +1217,7 @@ let rec do_try_open_block s =
     prerr_flags ("<= try open ``"^string_of_block s^"''")
       ;;
 
-let try_open_block s args =
+let try_open_block s _ =
   push stacks.s_insert_attr flags.insert_attr ;
   begin match flags.insert_attr with
   | Some (TR,_) when s <> TR -> ()
@@ -1405,7 +1405,6 @@ let rec force_block s content =
   let true_s = if s = FORGET then pblock() else s in
   let insert = flags.insert
   and insert_attr = flags.insert_attr
-  and was_nostyle = !cur_out.nostyle
   and was_top = !cur_out.top in
 
   do_close_mods () ;
@@ -1474,7 +1473,7 @@ and close_block_loc pred s =
 
 and open_block s args =
  if !verbose > 2 then begin
-   prerr_endline ("=> open_block ``"^string_of_block s^"''");
+   prerr_endline ("=> open_block ``"^string_of_block s^"''"^" arg="^args);
    pretty_cur !cur_out ;
  end ;
  try_flush_par (Wait s);
@@ -1631,6 +1630,50 @@ let horizontal_line attr width height =
   close_block GROUP
 ;;
 
+let skip_column s =
+    put ("&nbsp;</TD><TD NOWRAP ALIGN=center "^s^">")
+;;    
+
+let arrow_in_three_cols dir =
+  if dir then begin
+    put "<TABLE BGCOLOR=black BORDER=0 WIDTH=\"100%\" CELLSPACING=0 " ;
+    put "CELLPADDING=1><TR><TD></TD></TR></TABLE>" ;
+    put "</TD><TD>" ;
+    put "<TABLE BGCOLOR=black BORDER=0 WIDTH=\"100%\" CELLSPACING=0 " ;
+    put ("CELLPADDING=1><TR><TD></TD></TR></TABLE>") ;
+    put "</TD><TD STYLE=\"font-size:smaller\">&#9654;"
+  end
+  else begin
+    put "&#9664;</TD><TD>" ;
+    put "<TABLE BGCOLOR=black BORDER=0 WIDTH=\"100%\" CELLSPACING=0 " ;
+    put "CELLPADDING=1><TR><TD></TD></TR></TABLE>" ;
+    put "</TD><TD>" ;
+    put "<TABLE BGCOLOR=black BORDER=0 WIDTH=\"100%\" CELLSPACING=0 " ;
+    put ("CELLPADDING=1><TR><TD></TD></TR></TABLE>")
+  end 
+;;
+
+
+let arrow_in_table h dir =
+  let pad = (h-1)/2 in
+  if dir then begin
+    put "<TABLE BORDER=0 WIDTH=\"100%\" CELLSPACING=0 CELLPADDING=0>" ;
+    put "<TR><TD>" ;
+    put "<TABLE BGCOLOR=black BORDER=0 WIDTH=\"100%\" CELLSPACING=0 CELLPADDING=" ;
+    put (string_of_int pad) ;
+    put "><TR><TD></TD></TR></TABLE>" ;
+    put "</TD><TD>&gt</TD></TR></TABLE>"
+  end
+  else begin
+    put "<TABLE BORDER=1 WIDTH=\"100%\" CELLSPACING=0 CELLPADDING=0>" ;
+    put "<TR><TD>&lt</TD><TD>" ;
+    put "<TABLE BGCOLOR=black BORDER=1 WIDTH=\"100%\" CELLSPACING=0 CELLPADDING=" ;
+    put (string_of_int pad) ;
+    put "><TR><TD></TD></TR></TABLE>" ;
+    put "</TD></TR></TABLE>"
+  end 
+;;
+
 let line_in_table h =
   let pad = (h-1)/2 in
   put "<TABLE BORDER=0 WIDTH=\"100%\" CELLSPACING=0 CELLPADDING=" ;
