@@ -9,7 +9,7 @@
 (*                                                                     *)
 (***********************************************************************)
 
-let header = "$Id: htmlMath.ml,v 1.23 2003/03/07 17:25:33 maranget Exp $" 
+let header = "$Id: htmlMath.ml,v 1.33 2005/03/17 16:46:07 maranget Exp $" 
 
 
 open Misc
@@ -76,7 +76,7 @@ let put_in_math s =
 (* DISPLAYS *)
 (*----------*)
 
-let open_center () =  open_block DIV "ALIGN=center"
+let open_center () =  open_block DIV "CLASS=\"center\""
 and close_center () = close_block DIV
 ;;
 
@@ -112,7 +112,7 @@ let open_display_varg varg =
   end ;
   try_open_display () ;
   open_block DISPLAY varg ;
-  open_block TD "NOWRAP" ;
+  open_block TD "NOWRAP " ;
   open_block INTERN "" ;
   if !verbose > 2 then begin
     pretty_cur !cur_out ;
@@ -120,6 +120,26 @@ let open_display_varg varg =
   end     
 ;;
 
+(************************************************************************
+*									*
+*    To open display with vertical and horizontal alignment arguments   *
+*                                                                       *
+************************************************************************)
+
+let open_display_varg_harg varg harg = 
+  if !verbose > 2 then begin
+    Printf.fprintf stderr "open_display: "
+  end ;
+  try_open_display () ;
+  open_block DISPLAY (varg^harg);
+  open_block TD "NOWRAP" ;
+  open_block INTERN "" ;
+  if !verbose > 2 then begin
+    pretty_cur !cur_out ;
+    prerr_endline ""
+  end
+;;
+
 let open_display () = open_display_varg "VALIGN=middle"
 
 let close_display () =
@@ -274,8 +294,6 @@ let close_maths display =
   if display then close_center ()
 ;;
 
-
-
 (* vertical display *)
 
 let open_vdisplay display =  
@@ -290,11 +308,11 @@ and close_vdisplay () =
     prerr_endline "close_vdisplay";
   close_block TABLE
 
-and open_vdisplay_row s =
+and open_vdisplay_row trarg tdarg  =
   if !verbose > 1 then
     prerr_endline "open_vdisplay_row";
-  open_block TR "" ;
-  open_block TD s ;
+  open_block TR trarg ;
+  open_block TD tdarg ;
   open_display ()
 
 and close_vdisplay_row () =
@@ -309,22 +327,8 @@ and close_vdisplay_row () =
 
 (* Sup/Sub stuff *)
 
-let get_script_font () =
-  let n = get_fontsize () in
-  if n >= 3 then Some (n-1) else None
-;;
-
-let open_script_font () =
-  if not !pedantic then
-    match get_script_font () with
-    | Some m -> open_mod (Font m)
-    | _ -> ()
-;;
-
-
 let put_sup_sub display scanner (arg : string Lexstate.arg) =
   if display then open_display () else open_block INTERN "" ;
-  open_script_font () ;
   scanner arg ;
   if display then close_display () else close_block INTERN ;
 ;;
@@ -359,16 +363,16 @@ let standard_sup_sub scanner what sup sub display =
     force_item_display () ;
     open_vdisplay display ;
     if sup <> "" then begin
-      open_vdisplay_row "NOWRAP" ;
+      open_vdisplay_row "" "NOWRAP" ;
       clearstyle () ;
       put sup ;
       close_vdisplay_row ()
     end ;           
-    open_vdisplay_row "" ;
+    open_vdisplay_row "" "" ;
     what ();
     close_vdisplay_row () ;
     if sub <> "" then begin
-      open_vdisplay_row "NOWRAP" ;
+      open_vdisplay_row "" "NOWRAP" ;
       clearstyle () ;
       put sub ;
       close_vdisplay_row ()
@@ -391,13 +395,13 @@ let limit_sup_sub scanner what sup sub display =
   else begin
     force_item_display () ;
     open_vdisplay display ;
-    open_vdisplay_row "ALIGN=center" ;
+    open_vdisplay_row "" "ALIGN=center NOWRAP" ;
     put sup ;
     close_vdisplay_row () ;
-    open_vdisplay_row "ALIGN=left" ;
+    open_vdisplay_row "" "ALIGN=center NOWRAP" ;
     what () ;
     close_vdisplay_row () ;
-    open_vdisplay_row "ALIGN=center" ;
+    open_vdisplay_row "" "ALIGN=center NOWRAP" ;
     put sub ;
     close_vdisplay_row () ;
     close_vdisplay () ;
@@ -415,15 +419,15 @@ let int_sup_sub something vsize scanner what sup sub display =
   end ;
   if sup <> "" || sub <> "" then begin
     open_vdisplay display ;
-    open_vdisplay_row "ALIGN=left NOWRAP" ;
+    open_vdisplay_row "" "ALIGN=left NOWRAP" ;
     put sup ;
     close_vdisplay_row () ;
-    open_vdisplay_row "ALIGN=left" ;
+    open_vdisplay_row "" "ALIGN=left" ;
     for i = 2 to vsize do
       skip_line ()
     done ;
     close_vdisplay_row () ;
-    open_vdisplay_row "ALIGN=left NOWRAP" ;
+    open_vdisplay_row "" "ALIGN=left NOWRAP" ;
     put sub ;
     close_vdisplay_row () ;
     close_vdisplay () ;
@@ -453,7 +457,7 @@ let insert_vdisplay open_fun =
     push_out out_stack (bs,bargs,bout) ;    
     close_display () ;
     cur_out := ppout ;
-    open_fun () ;
+    let () = open_fun () in (* force 'unit -> unit' type  *)
     do_put (Out.to_string new_out.out) ;
     flags.empty <- false ; flags.blank <- false ;
     free new_out ;    
@@ -471,23 +475,23 @@ let insert_vdisplay open_fun =
 
 
 
-let over display lexbuf =
+let over display _lexbuf =
   if display then begin
     let mods = insert_vdisplay
         (fun () ->
           open_vdisplay display ;
-          open_vdisplay_row "NOWRAP ALIGN=center") in
+          open_vdisplay_row "" "NOWRAP ALIGN=center") in
     close_vdisplay_row () ;
 (*
     open_vdisplay_row "" ;
     close_mods () ;
     horizontal_line  "NOSHADE" Length.Default (Length.Pixel 2);
 *)
-    open_vdisplay_row "BGCOLOR=black" ;
+    open_vdisplay_row "" "BGCOLOR=black" ;
     close_mods () ;
     line_in_table 3 ;
     close_vdisplay_row () ;
-    open_vdisplay_row "NOWRAP ALIGN=center" ;
+    open_vdisplay_row "" "NOWRAP ALIGN=center" ;
     close_mods () ;
     open_mods mods ;
     freeze
@@ -499,6 +503,76 @@ let over display lexbuf =
   end
 ;;
 
+(********************************************************
+ *  For use by                                          *
+ *      \cfrac to align arguments to the left or right  *
+ *      \xleftarrow and \xrightarrow to print the arrow *
+ *          instead of the fraction bar                 *
+ ********************************************************)
+
+let over_align align1 align2 display _lexbuf =
+  if align1 then begin
+    let mods = insert_vdisplay
+      (fun () ->
+        open_vdisplay display ;
+        open_vdisplay_row
+          "" ("NOWRAP STYLE=\"font-size:smaller\" ALIGN=center") ;
+        skip_column "STYLE=\"font-size:smaller\"") in
+    skip_column "STYLE=\"font-size:smaller\"" ;
+    close_vdisplay_row () ;
+    open_vdisplay_row "" "STYLE=\"font-size:smaller\"" ;
+    close_mods () ;
+    arrow_in_three_cols align2 ;
+    close_vdisplay_row () ;
+    open_vdisplay_row "" ("NOWRAP STYLE=\"font-size:smaller\" ALIGN=center") ;
+    skip_column "STYLE=\"font-size:smaller\"" ;
+    close_mods () ;
+    open_mods mods ;
+    freeze
+      (fun () ->
+        skip_column "STYLE=\"font-size:smaller\"" ;
+        close_vdisplay_row () ;
+        close_vdisplay ();)
+  end
+  else begin
+    let alignment = if align2 then "ALIGN=right" else "ALIGN=left" in
+    if display then begin
+      let mods = insert_vdisplay
+        (fun () ->
+          open_vdisplay display ;
+          open_vdisplay_row "" ("NOWRAP "^alignment)) in
+      close_vdisplay_row () ;
+      open_vdisplay_row "" "BGCOLOR=black" ;
+      close_mods () ;
+      line_in_table 3 ;
+      close_vdisplay_row () ;
+      open_vdisplay_row "" ("NOWRAP "^alignment) ;
+      close_mods () ;
+      open_mods mods ;
+      freeze
+        (fun () ->
+          close_vdisplay_row () ;
+          close_vdisplay ();)
+    end 
+    else begin
+      put "/"
+    end
+  end
+;;
+
+let box_around_display scanner arg = 
+    open_block TABLE "border=\"2\" cellspacing=0 cellpadding=1" ;
+    open_block TR "" ;
+    open_block TD "NOWRAP" ;
+    open_vdisplay true ;
+    open_vdisplay_row "" ("NOWRAP ALIGN=center") ;
+    scanner arg ;
+    close_vdisplay_row () ;
+    close_vdisplay () ;
+    close_block TD ;
+    close_block TR ;
+    close_block TABLE
+;;
 
 (* Gestion of left and right delimiters *)
 
