@@ -9,7 +9,7 @@
 (*                                                                     *)
 (***********************************************************************)
 
-let header = "$Id: latexmacros.ml,v 1.66 2002/04/29 14:31:03 maranget Exp $" 
+let header = "$Id: latexmacros.ml,v 1.69 2005/03/03 15:33:28 maranget Exp $" 
 open Misc
 open Parse_opts
 open Lexstate
@@ -165,11 +165,13 @@ and exec_init name =
      prerr_endline ("Initializing primitives for package: "^name) ;
   try
     let f = Hashtbl.find prim_table name in
+    Hashtbl.remove prim_table name ; (* accidental double is possible... *)
     try f () with
       Failed ->
         Misc.warning
          ("Bad trip while initializing primitives for package: "^name)
-  with Not_found -> ()
+  with Not_found ->
+    Misc.warning ("Cannot find primitives for package: "^name)
 ;;   
 
 
@@ -208,6 +210,9 @@ and global_def name pat action =
   end ;
   hidden_global_def name (pat,action)
 
+and global_undef name =
+  Hashtbl.remove global_table name ;
+  Hashtbl.remove local_table name
 ;;
 
 let def_init name f =
