@@ -9,7 +9,7 @@
 (*                                                                     *)
 (***********************************************************************)
 
-let header = "$Id: lexstate.ml,v 1.60 2002/05/21 13:38:54 maranget Exp $"
+let header = "$Id: lexstate.ml,v 1.65 2005/03/08 15:15:03 maranget Exp $"
 
 open Misc
 open Lexing
@@ -114,10 +114,7 @@ exception Error of string
 let display = ref false
 and raw_chars = ref false
 and in_math = ref false
-and french =
-  ref
-    (match !Parse_opts.language with
-    | Parse_opts.Francais -> true | _ -> false)
+and whitepre = ref false
 and optarg = ref false
 and styleloaded = ref false
 and activebrace = ref true
@@ -190,11 +187,14 @@ let plain_of_char = function
   | '~' -> 7
   | '\\' -> 8
   | '%'  -> 9
+  | '\'' -> 10
+  | '`' -> 11
+  | '-' -> 12
   | c   ->
       raise
         (Fatal ("Internal catcode table error: '"^String.make 1 c^"'"))
 
-and plain = Array.create 10 true
+and plain = Array.create 13 true
 
 let is_plain c = plain.(plain_of_char c)
 and set_plain c = plain.(plain_of_char c) <- true
@@ -518,7 +518,7 @@ let rec parse_args_norm pat lexbuf = match pat with
 | s :: pat when not (norm_arg s) ->
     Save.skip_delim s lexbuf ;
     parse_args_norm pat lexbuf
-| s :: pat ->
+| _ :: pat ->
     let arg = save_arg lexbuf in
     let r = parse_args_norm pat lexbuf in
     arg :: r
@@ -585,8 +585,8 @@ let scan_this lexfun s =
     Printf.fprintf stderr "scan_this : [%s]" s ;
     prerr_endline ""  
   end ;
-  let lexer = Lexing.from_string s in
-  let r = lexfun lexer in
+  let lexbuf = Lexing.from_string s in
+  let r = lexfun lexbuf in
   if !verbose > 1 then begin
     Printf.fprintf stderr "scan_this : over" ;
     prerr_endline ""
@@ -601,8 +601,8 @@ and scan_this_arg lexfun {arg=s ; subst=this_subst } =
     Printf.fprintf stderr "scan_this_arg : [%s]" s ;
     prerr_endline ""  
   end ;
-  let lexer = Lexing.from_string s in
-  let r = lexfun lexer in
+  let lexbuf = Lexing.from_string s in
+  let r = lexfun lexbuf in
   if !verbose > 1 then begin
     Printf.fprintf stderr "scan_this_arg : over" ;
     prerr_endline ""
