@@ -9,7 +9,7 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(*  $Id: package.ml,v 1.43 2003/09/29 08:54:54 maranget Exp $    *)
+(*  $Id: package.ml,v 1.69 2005/03/08 15:15:03 maranget Exp $    *)
 
 module type S = sig  end
 
@@ -49,8 +49,8 @@ def_print "\\@heveacomline"
 def_print "\\@heveaversion" Version.version ;
 def_print "\\@hevealibdir" Mylib.libdir
 ;;
-(* Unicode entities given in hexa *)
 
+(* Unicode entities given in hexa *)
 def_code "\\@unicode"
  (fun lexbuf ->
    let arg = get_prim_arg lexbuf in
@@ -126,7 +126,7 @@ and call_prim lexbuf =
   scan_this  main exec
 
 and call_subst_opt lexbuf =
-  let csname = get_csname lexbuf in
+  let csname = get_csname lexbuf in  
   let default = subst_arg lexbuf in
   let arg = subst_arg lexbuf in
   let lb = Lexing.from_string arg in
@@ -140,14 +140,32 @@ and call_subst_opt lexbuf =
   scan_this  main exec
 ;;
 
-
-
 def_code "\\@funcall" call_subst ;
 def_code "\\@callsubst" call_subst ;
 def_code "\\@callsubstopt" call_subst_opt ;
 def_code "\\@callprim" call_prim ;
 ;;
 
+def_code "\\@calloptsimple"
+  (fun lexbuf ->
+    let csname = get_csname lexbuf in
+    let arg = subst_arg lexbuf in
+    let lb = Lexing.from_string arg in
+    let opt = try Some (Save.opt lb) with Save.NoOpt -> None in
+    let rem =  Save.remain lb in
+    let exec =
+       match opt with
+       | None ->  csname ^ "{" ^ rem ^ "}"
+       | Some opt -> csname ^ "[" ^ opt ^ "]{" ^ rem ^ "}" in
+    if !verbose > 1 then begin
+      prerr_string "\\@calloptsimple: " ;
+      prerr_endline exec ;
+    end ;
+    scan_this  main exec
+  )
+;;
+
+
 (* Haux files parsing hooks before and after reading the file *)
 def_code "\\@hauxinit"
   (fun lexbuf ->
@@ -317,21 +335,28 @@ register_init "color"
         Color.define clr mdl value ;
         Color.define_named clr mdl value) ;
 
-    def_code "\\@getcolor"
-      (fun lexbuf ->
-        let mdl = get_prim_opt "!*!" lexbuf in    
-        let clr = get_prim_arg lexbuf in
-        let htmlval = match mdl with
-        | "!*!"|"" -> Color.retrieve clr
-        | _     -> Color.compute mdl clr in
-        Dest.put_char '"' ;
-        Dest.put_char '#' ;
-        Dest.put htmlval ;
-        Dest.put_char '"'))
+    let do_getcolor c lexbuf =
+      let mdl = get_prim_opt "!*!" lexbuf in    
+      let clr = get_prim_arg lexbuf in
+      let htmlval = match mdl with
+      | "!*!"|"" -> Color.retrieve clr
+      | _     -> Color.compute mdl clr in
+      Dest.put c ;
+      begin match htmlval with
+        | Color.Hex x -> Dest.put_char '#' ; Dest.put x
+        | Color.Name n -> Dest.put n
+      end ;
+      Dest.put c in
+    def_code "\\@getcolor" (do_getcolor "\"") ;
+    def_code "\\@getstylecolor" (do_getcolor "") ;
+    ())
 ;;
 
 register_init "colortbl"
     (fun () ->
+      let color_to_string = function
+        | Color.Hex x -> "#"^x
+        | Color.Name n -> n in
       def_code "\\columncolor"
         (fun lexbuf ->
           let mdl = get_prim_opt "!*!" lexbuf in    
@@ -341,7 +366,7 @@ register_init "colortbl"
           | _     -> Color.compute mdl clr in
           skip_opt lexbuf ;
           skip_opt lexbuf ;
-          Dest.insert_attr "TD" ("bgcolor=\"#"^htmlval^"\"")) ;
+          Dest.insert_attr "TD" ("bgcolor=\""^color_to_string htmlval^"\"")) ;
       def_code "\\rowcolor"
         (fun lexbuf ->
           let mdl = get_prim_opt "!*!" lexbuf in    
@@ -351,7 +376,7 @@ register_init "colortbl"
           | _     -> Color.compute mdl clr in
           skip_opt lexbuf ;
           skip_opt lexbuf ;
-          Dest.insert_attr "TR" ("bgcolor=\"#"^htmlval^"\"")))
+          Dest.insert_attr "TR" ("bgcolor=\""^color_to_string htmlval^"\"")))
 ;;
 
 
@@ -360,7 +385,7 @@ register_init "sword"
 (fun () ->
       def_code "\\FRAME"
         (fun lexbuf ->
-          let lxm = lexeme lexbuf in
+          let _ = lexeme lexbuf in
           (* discard the first 7 arguments *)
           let _ = save_arg lexbuf in 
           let _ = save_arg lexbuf in
@@ -400,7 +425,7 @@ fallback name");
       (*    arg1 = hex number w/o leading 0, eg x23ab *)
       (*    arg2 = decimal equivalent, eg 9131 *)
       (* it is up to \swUNICODE (in sword.hva) to do final formatting *) 
-      let lxm = lexeme lexbuf in
+      let _ = lexeme lexbuf in
       let t = Subst.subst_arg lexbuf in
       let s = string_of_int (int_of_string (t)) in
       let tt = String.sub t (String.index t 'x') (-1+String.length t) in
@@ -489,7 +514,7 @@ register_init "hyperref"
       (fun lexbuf ->
         let _ = save_arg lexbuf in
         Save.start_echo () ;
-        let url = save_arg lexbuf in
+        let _ = save_arg lexbuf in
         let url = Save.get_echo () in
         let category = get_prim_arg lexbuf in
         let name = get_prim_arg lexbuf in
@@ -617,7 +642,6 @@ register_init "xypic"
   )
 ;;
 
-
 register_init "natbib"
   (fun () ->
     def_code "\\NAT@write"
@@ -638,6 +662,224 @@ register_init "natbib"
           | Some s -> s in
         scan_this main ("\\NAT@args" ^ arg)) ;
     ())
-            
+;;            
+
+let get_elements str = 
+    let len = String.length str in
+    let rec all_elements l = match l with
+      0 -> []
+    | n -> (all_elements (n-1))@[(String.sub str (n-1) 1)] in
+    all_elements len
+;;   
+
+let str_cat x y = x^y
+;;
+
+def_code "\\@mathbb"
+  (fun lexbuf -> 
+    let arg1 = save_arg lexbuf in
+    let str = arg1.arg in
+    (*let dummy = print_string str in*)
+    let str_list = get_elements str in
+    (*let h = List.hd str_list in
+    let dummy = print_string h in*)
+    let format x = Scan.get_this_main ("\\"^"one@mathbb{"^x^"}") in
+    let formatted_list = List.map format str_list in
+    let formatted_text = List.fold_left str_cat "" formatted_list in
+    (*print_string ("<<"^formatted_text^">>\n") ;*) 
+    Dest.put formatted_text
+  )
+;;
+
+def_code "\\@mathfrak"
+  (fun lexbuf -> 
+    let str = subst_arg lexbuf in
+    let str_list = get_elements str in
+    let format x = Scan.get_this_main ("\\"^"one@mathfrak{"^x^"}") in
+    let formatted_list = List.map format str_list in
+    let formatted_text = List.fold_left str_cat "" formatted_list in
+    Dest.put formatted_text
+  )
+;;
+
+def_code "\\@mathsf"
+  (fun lexbuf -> 
+    let str = subst_arg lexbuf in
+    let str_list = get_elements str in
+    let format x = Scan.get_this_main ("\\"^"one@mathsf{"^x^"}") in
+    let formatted_list = List.map format str_list in
+    let formatted_text = List.fold_left str_cat "" formatted_list in
+    Dest.put formatted_text
+  )
+;;
+
+def_code "\\@mathbf"
+  (fun lexbuf -> 
+    let str = subst_arg lexbuf in
+    (*let str_list = get_elements str in
+    let format x = Scan.get_this_main ("\\"^"one@mathbf{"^x^"}") in
+    let formatted_list = List.map format str_list in
+    let formatted_text = List.fold_left str_cat "" formatted_list in*)
+    Dest.put ("<B>"^str^"</B>")
+  )
+;;
+
+def_code "\\@mathrm"
+  (fun lexbuf -> 
+    let arg1 = save_arg lexbuf in
+    let str = arg1.arg in
+    (*let str_list = get_elements str in
+    let format x = Scan.get_this_main ("\\"^"one@mathbf{"^x^"}") in
+    let formatted_list = List.map format str_list in
+    let formatted_text = List.fold_left str_cat "" formatted_list in*)
+    Dest.put (str)
+  )
+;;
+
+def_code "\\@mathcal"
+  (fun lexbuf -> 
+    let arg1 = save_arg lexbuf in
+    let str = arg1.arg in
+    let str_list = get_elements str in
+    let format x = Scan.get_this_main ("\\"^"one@mathcal{"^x^"}") in
+    let formatted_list = List.map format str_list in
+    let formatted_text = List.fold_left str_cat "" formatted_list in
+    Dest.put formatted_text
+  )
+;;
+
+def_code "\\@mathtt"
+  (fun lexbuf -> 
+    let arg1 = save_arg lexbuf in
+    let str = arg1.arg in
+    let str_list = get_elements str in
+    let format x = Scan.get_this_main ("\\"^"one@mathtt{"^x^"}") in
+    let formatted_list = List.map format str_list in
+    let formatted_text = List.fold_left str_cat "" formatted_list in
+    Dest.put formatted_text
+  )
+;;
+
+
+(*
+def_code "\\xrightarrow"
+  (fun lexbuf ->
+    let optarg = save_opt "" lexbuf in
+    let arg = save_arg lexbuf in
+    Dest.open_block "TABLE" "border=0 cellpadding=0 cellspacing=0";
+    Dest.open_block "SMALL" "" ;
+    Dest.open_block "TR" "" ;
+    Dest.open_block "TD" "" ;
+    Dest.put "&nbsp;&nbsp; " ;
+    Dest.close_block "TD" ;
+    Dest.open_block "TD" "align=center valign=bottom" ;
+    scan_this_arg Scan.main arg;
+    Dest.close_block "TD" ;
+    Dest.open_block "TD" "color=black" ;
+    Dest.put "&nbsp;" ;
+    Dest.close_block "TD" ;
+    Dest.close_block "TR" ;
+    Dest.close_block "SMALL";
+
+    Dest.open_block "TR" "" ;
+    Dest.open_block "TD" "ALIGN=right" ;
+    Dest.put ("<TABLE border=0 cellspacing=0 cellpadding=1 bgcolor=black "^
+	      "width=\"100%\"><TR><TD></TD></TR></TABLE>") ;
+    Dest.close_block "TD" ;
+    Dest.open_block "TD" "align=center" ;
+    Dest.put ("<TABLE border=0 cellspacing=0 cellpadding=1 bgcolor=black "^
+	      "width=\"100%\"><TR><TD></TD></TR></TABLE>") ;
+    Dest.close_block "TD" ;
+    Dest.open_block "TD" "ALIGN=left" ;
+    Dest.put "&gt" ;
+    Dest.close_block "TD" ; 
+    Dest.close_block "TR" ;
+
+    Dest.open_block "SMALL" "" ;
+    Dest.open_block "TR" "" ;
+    Dest.open_block "TD" "" ;
+    Dest.put "&nbsp;" ;
+    Dest.close_block "TD" ;
+    Dest.open_block "TD" "align=center valign=top" ;
+    scan_this_arg Scan.main optarg;
+    Dest.close_block "TD" ;
+    Dest.open_block "TD" "" ;
+    Dest.put "&nbsp;" ;
+    Dest.close_block "TD" ;
+    Dest.close_block "TR" ;
+    Dest.close_block "SMALL" ;
+    Dest.close_block "TABLE")
+;;
+
+
+def_code "\\xleftarrow"
+  (fun lexbuf ->
+    let optarg = save_opt "" lexbuf in
+    let arg = save_arg lexbuf in
+    Dest.open_block "TABLE" "border=0 cellpadding=0 cellspacing=0";
+    Dest.open_block "SMALL" "" ;
+    
+    Dest.open_block "TR" "" ;
+    Dest.open_block "TD" "align=center valign=bottom" ;
+    scan_this_arg Scan.main arg;
+    Dest.close_block "TD" ;
+    Dest.close_block "TR" ;
+
+    Dest.open_block "TR" "" ;
+    Dest.open_block "TD" "align=center style=\"font-size:7pt;\"" ;
+    Dest.put "&larr;&mdash;&mdash;&mdash;&mdash;" ;
+    Dest.close_block "TD" ; 
+    Dest.close_block "TR" ;
+
+    Dest.open_block "TR" "" ;
+    Dest.open_block "TD" "align=center valign=top" ;
+    scan_this_arg Scan.main optarg;
+    Dest.close_block "TD" ;
+    Dest.close_block "TR" ;
+    Dest.close_block "SMALL" ;
+    Dest.close_block "TABLE")
+;;
+*)
+(*
+def_code "\\cfrac"
+  (fun lexbuf ->
+    let optarg = save_opt "" lexbuf in
+    let arg_up = save_arg lexbuf in
+    let arg_down = save_arg lexbuf in
+    let opt_str = optarg.arg in
+    let align = match opt_str with
+      "l" -> "align=left"
+    | "r" -> "align=right"
+    | "" ->  "align=center"  
+    | _ -> "align=center" (* WARNING : need to give appropriate warning *) in
+    Dest.open_block "TABLE" "border=0 cellpadding=0 cellspacing=0";
         
-end
+    Dest.open_block "TR" "" ;
+    Dest.open_block "TD" (align^" valign=bottom") ;
+    scan_this_arg Scan.main arg_up;
+    Dest.close_block "TD" ;
+    Dest.close_block "TR" ;
+
+    Dest.open_block "TR" "" ;
+    Dest.open_block "TD" "bgcolor=black" ;
+    Dest.open_block "TABLE" 
+      "border=0 width=\"100%\" cellspacing=0 cellpadding=1" ;
+    Dest.open_block "TR" "" ;
+    Dest.open_block "TD" "";
+    Dest.close_block "TD" ; 
+    Dest.close_block "TR" ;
+    Dest.close_block "TABLE" ;
+    Dest.close_block "TD" ; 
+    Dest.close_block "TR" ;
+
+    Dest.open_block "TR" "" ;
+    Dest.open_block "TD" (align^" valign=top") ;
+    scan_this_arg Scan.main arg_down;
+    Dest.close_block "TD" ;
+    Dest.close_block "TR" ;
+    Dest.close_block "TABLE")
+;;
+*)
+
+
+ end
