@@ -9,7 +9,7 @@
 (*                                                                     *)
 (***********************************************************************)
 
-let header = "$Id: text.ml,v 1.58 2003/02/13 14:51:01 maranget Exp $"
+let header = "$Id: text.ml,v 1.65 2005/03/29 10:46:27 maranget Exp $"
 
 
 open Misc
@@ -155,7 +155,7 @@ let pretty_stack s =
 
 let rec pop_out s = match pop s with
   Normal (a,b,c) -> a,b,c
-| Freeze f       -> raise PopFreeze
+| Freeze _       -> raise PopFreeze
 ;;
 
 let free_list = ref [];;
@@ -194,7 +194,7 @@ let set_out out =
   !cur_out.out <- out
 ;;
 
-let newstatus nostyle p a t = match !free_list with
+let newstatus nostyle _ a t = match !free_list with
   [] ->
     { nostyle = nostyle;
       active = a;
@@ -692,7 +692,7 @@ let close_mod () = match !cur_out.active with
 | _ -> ()
 ;;
 
-let erase_mods ml = ()
+let erase_mods _ = ()
 ;;
 
 let rec open_mods = function
@@ -706,7 +706,7 @@ let close_mods () =
 ;;
 
 let par = function (*Nombre de lignes a sauter avant le prochain put*)
-  | Some n as p->
+  | Some n ->
       begin
 	flags.pending_par <-
 	  (match pblock() with
@@ -957,7 +957,6 @@ let do_item isnum =
     prerr_string "do_item: stack=";
     pretty_stack out_stack
   end;
-  let mods = !cur_out.active in
   if flags.nitems = 0 then begin let _ = forget_par () in () end ;
   try_flush_par () ;
   flags.nitems<-flags.nitems+1;
@@ -967,18 +966,16 @@ let do_item isnum =
     do_put "\n- "
 ;;
 
-let item () = do_item false
-and nitem () = do_item true
+let item _ = do_item false
+and nitem _ = do_item true
 ;;
 
-    
-let ditem scan arg =
+let ditem scan arg _ _ =
   if !verbose > 2 then begin
     prerr_string "ditem: stack=";
     pretty_stack out_stack
   end;
   
-  let mods = !cur_out.active in
   let true_scan =
     if flags.nitems = 0 then begin
       let _ = forget_par() in ();
@@ -993,8 +990,6 @@ let ditem scan arg =
   do_put_char ' '
 ;;
 
-
-
 let erase_block s = 
   if not !cur_out.temp then close_block s
   else begin
@@ -1198,7 +1193,6 @@ let cell = ref {
 } 
 ;;
 
-
 let row= ref {
   haut = 0;
   cells = Tabl (Table.create  !cell)
@@ -1559,6 +1553,14 @@ let text_out j hauteur height align =
 ;;
 (* dis si oui ou non on affiche la ligne de cette cellule, etant donne l'alignement vertical.*)
 
+let safe_string_make n c =
+  if n >= 0 then
+    String.make n c
+  else begin
+    warning (Printf.sprintf "Text.put_line: negative line: %i '%c'\n" n c) ;
+    "" 
+  end
+
 let put_ligne texte pos align width taille wrap=
 (* envoie la ligne de texte apres pos, sur out, en alignant horizontalement et en completant pour avoir la bonne taille *)
   let pos_suiv = try 
@@ -1577,15 +1579,15 @@ let put_ligne texte pos align width taille wrap=
 
   let ligne = match align with
   | Left -> String.concat "" 
-	[s; String.make (taille-t+post) ' ']
+	[s; safe_string_make (taille-t+post) ' ']
   | Center -> String.concat ""
-	[String.make ((taille-t)/2) ' ';
+	[safe_string_make ((taille-t)/2) ' ';
 	  s;
-	  String.make (taille - t + post- (taille-t)/2) ' '] 
+	  safe_string_make (taille - t + post- (taille-t)/2) ' '] 
   | Right -> String.concat ""
-	[String.make (taille-t) ' ';
+	[safe_string_make (taille-t) ' ';
 	  s;
-	  String.make (post) ' ']
+	  safe_string_make (post) ' ']
    in
   if !verbose>2 then prerr_endline ("line sent :#"^ligne^"#");
   do_put ligne;
@@ -1754,11 +1756,14 @@ let image arg n =
   end
 ;;
 
-let horizontal_line s width height =
+let horizontal_line s width height =  
   if flags.in_table then begin
-    !cell.w <- 0;
-    !cell.wrap <- Fill;
-    put_char '-';
+    Printf.eprintf "HR: %s %s %s\n" s (Length.pretty width) (Length.pretty height) ;
+    if false &&  not (Length.is_zero width || Length.is_zero height) then begin
+      !cell.w <- 0;
+      !cell.wrap <- Fill;
+      put_char '-'
+    end
   end else begin
     open_block "INFO" "";
     finit_ligne ();
@@ -1916,7 +1921,7 @@ and close_maths display =
     prerr_endline "close_maths";
 ;;
 
-
+let box_around_display scanner arg = ();;
 
 let open_vdisplay display = 
   open_table (!verbose>1) "";
@@ -2094,6 +2099,9 @@ let translate = function
 | s   -> s
 ;;
 
+let over_align align1 align2 display lexbuf = over display lexbuf
+;;
+
 let left delim k =
   item_display ();
   open_display "";
