@@ -7,7 +7,7 @@
 (*  Copyright 2001 Institut National de Recherche en Informatique et   *)
 (*  Automatique.  Distributed only by permission.                      *)
 (*                                                                     *)
-(*  $Id: ultra.ml,v 1.8 2001/06/05 17:57:41 maranget Exp $             *)
+(*  $Id: ultra.ml,v 1.10 2005/02/25 17:49:18 maranget Exp $             *)
 (***********************************************************************)
 
 open Tree
@@ -122,10 +122,6 @@ and correct_cfl_high ts i1 j1 i2 j2 =
   else
     j1
 
-
-
-
-
 let rec mk_cover_one ts i j f = function
   | [] -> (i,j),f
   | ((ii,jj),g)::rem ->
@@ -148,18 +144,7 @@ let extend_neutrals ts fs =
 let factorize low high ts =
   if low >= high then []
   else
-  let extend_blanks_left i =
-    let rec do_rec i =
-      if i <= low then low
-      else begin
-        if is_blank ts.(i-1) then
-          do_rec (i-1)
-        else
-          i
-      end in
-    do_rec i
-
-  and limit_blanks_right i =
+    let limit_blanks_right i =
     let rec do_rec i =
       if i <= low then low
       else begin
@@ -553,7 +538,7 @@ and opt top ts k =
   for i = 0 to l-1 do
     opt_onodes ts i
   done ;
-  let p =  is_text_blank in
+  let p = is_text_blank in
   let start,pre = cut_begin p ts l 0 in
   if start >= l then pre@k
   else
